@@ -1,7 +1,7 @@
 # function to summarize estimation results  2015-3-11 Thong Pham
 print.PA_result <- function(x,...){
-  cat("\nPA_result object contains estimated attachment function. \n");
-  cat("Number of bins: ", x$G,"\n");
+  cat("\nContaining the estimated attachment function. \n");
+  cat("Number of bins: ", x$g,"\n");
   cat("Estimated attachment exponent:", x$alpha, "\n");
   if (x$ci[1] == "N") {
     cat("No possible confidence interval for the estimated attachment exponent.\n");
